OC.L10N.register(
    "forms",
    {
    "Copy" : "Kopier",
    "Shared with you" : "Shared with you",
    "Select groups" : "Vel grupper",
    "Cancel" : "Cancel",
    "Required" : "Nødvendig",
    "Delete" : "Slett",
    "Other" : "Anna",
    "never" : "aldri",
    "Set expiration date" : "Set utløpsdato",
    "Group" : "Gruppe",
    "Share link" : "Del lenkje",
    "Edit" : "Rediger",
    "Share" : "Del",
    "Description" : "Skildring",
    "Summary" : "Oppsumering",
    "Download" : "Last ned",
    "Search" : "Søk",
    "Sharing" : "Deling",
    "Settings" : "Instillingar",
    "Abort" : "Avbryt",
    "File" : "Fil",
    "Date" : "Dato",
    "Time" : "Tid",
    "Color" : "Farge",
    "Uploading …" : "Lastar opp..."
},
"nplurals=2; plural=(n != 1);");
